@@ -8,6 +8,9 @@ import click
 @click.option(
     "--docker", is_flag=True, default=False, help="Run the SAM build in Docker."
 )
-def deploy(name, dir, docker):
-    deployer = Deployer(name, dir, docker=docker)
+@click.option(
+    "--local", is_flag=True, default=False, help="Build locally instead of using SAM."
+)
+def deploy(name, dir, docker, local):
+    deployer = Deployer(name, dir, docker=docker, local=local)
     deployer.deploy()
